@@ -65,7 +65,7 @@ mcmcBM<-function(tree,x,ngen=10000,control=list()){
 				sig2<-sig2.prime
 				L<-L.prime
 				Pr<-Pr.prime
-			} else if(i%%con$sample==0) X[i/con$sample+1,]<-c(i,sig2,a,xbar,intV,L.prime)
+			} else if(i%%con$sample==0) X[i/con$sample+1,]<-c(i,sig2,a,xbar,intV,L)
 		} else if(j==1){
 			# update a
 			a.prime<-a+rnorm(n=1,sd=sqrt(con$prop[j+1]))
@@ -77,7 +77,7 @@ mcmcBM<-function(tree,x,ngen=10000,control=list()){
 				a<-a.prime
 				L<-L.prime
 				Pr<-Pr.prime
-			} else if(i%%con$sample==0) X[i/con$sample+1,]<-c(i,sig2,a,xbar,intV,L.prime)
+			} else if(i%%con$sample==0) X[i/con$sample+1,]<-c(i,sig2,a,xbar,intV,L)
 		} else if(j>1&&j<=(n+1)) {
 			k<-j-1 # update tip mean k
 			xbar.prime<-xbar
@@ -90,7 +90,7 @@ mcmcBM<-function(tree,x,ngen=10000,control=list()){
 				xbar<-xbar.prime
 				L<-L.prime
 				Pr<-Pr.prime
-			} else if(i%%con$sample==0) X[i/con$sample+1,]<-c(i,sig2,a,xbar,intV,L.prime)
+			} else if(i%%con$sample==0) X[i/con$sample+1,]<-c(i,sig2,a,xbar,intV,L)
 		} else if(j>(n+1)){
 			# update var
 			intV.prime<-intV+rnorm(n=1,sd=sqrt(con$prop[j+1]))
@@ -103,7 +103,7 @@ mcmcBM<-function(tree,x,ngen=10000,control=list()){
 				intV<-intV.prime
 				L<-L.prime
 				Pr<-Pr.prime
-			} else if(i%%con$sample==0) X[i/con$sample+1,]<-c(i,sig2,a,xbar,intV,L.prime)	
+			} else if(i%%con$sample==0) X[i/con$sample+1,]<-c(i,sig2,a,xbar,intV,L)	
 		}
 	}
 
